@@ -23,176 +23,220 @@ from ....revision import NULL_REVISION
 from ....tests import TestCase, TestCaseWithTransport
 from ....tests.matchers import RevisionHistoryMatches
 from ....transport import NoSuchFile
-from ..rebase import (REBASE_CURRENT_REVID_FILENAME, REBASE_PLAN_FILENAME,
-                      CommitBuilderRevisionRewriter, RebaseState1,
-                      ReplaySnapshotError, WorkingTreeRevisionRewriter,
-                      generate_simple_plan, generate_transpose_plan,
-                      marshall_rebase_plan, rebase_todo,
-                      unmarshall_rebase_plan)
+from ..rebase import (
+    REBASE_CURRENT_REVID_FILENAME,
+    REBASE_PLAN_FILENAME,
+    CommitBuilderRevisionRewriter,
+    RebaseState1,
+    ReplaySnapshotError,
+    WorkingTreeRevisionRewriter,
+    generate_simple_plan,
+    generate_transpose_plan,
+    marshall_rebase_plan,
+    rebase_todo,
+    unmarshall_rebase_plan,
+)
 
 
 class RebasePlanReadWriterTests(TestCase):
-
     def test_simple_marshall_rebase_plan(self):
-        self.assertEqualDiff(b"""\
+        self.assertEqualDiff(
+            b"""\
 # Bazaar rebase plan 1
 1 bla
 oldrev newrev newparent1 newparent2
-""", marshall_rebase_plan((1, b"bla"),
-                          {b"oldrev": (b"newrev", (b"newparent1", b"newparent2"))}))
+""",
+            marshall_rebase_plan(
+                (1, b"bla"), {b"oldrev": (b"newrev", (b"newparent1", b"newparent2"))}
+            ),
+        )
 
     def test_simple_unmarshall_rebase_plan(self):
-        self.assertEqual(((1, b"bla"),
-                          {b"oldrev": (b"newrev", (b"newparent1", b"newparent2"))}),
-                          unmarshall_rebase_plan(b"""# Bazaar rebase plan 1
+        self.assertEqual(
+            ((1, b"bla"), {b"oldrev": (b"newrev", (b"newparent1", b"newparent2"))}),
+            unmarshall_rebase_plan(b"""# Bazaar rebase plan 1
 1 bla
 oldrev newrev newparent1 newparent2
-"""))
+"""),
+        )
 
     def test_unmarshall_rebase_plan_formatunknown(self):
-        self.assertRaises(UnknownFormatError,
-                          unmarshall_rebase_plan, b"""# Bazaar rebase plan x
+        self.assertRaises(
+            UnknownFormatError,
+            unmarshall_rebase_plan,
+            b"""# Bazaar rebase plan x
 1 bla
 oldrev newrev newparent1 newparent2
-""")
+""",
+        )
 
 
 class ConversionTests(TestCaseWithTransport):
-
     def test_simple(self):
-        wt = self.make_branch_and_tree('.')
+        wt = self.make_branch_and_tree(".")
         b = wt.branch
-        with open('hello', 'w') as f:
-            f.write('hello world')
-        wt.add('hello')
-        wt.commit(message='add hello', rev_id=b"bla")
-        with open('hello', 'w') as f:
-            f.write('world')
-        wt.commit(message='change hello', rev_id=b"bloe")
+        with open("hello", "w") as f:
+            f.write("hello world")
+        wt.add("hello")
+        wt.commit(message="add hello", rev_id=b"bla")
+        with open("hello", "w") as f:
+            f.write("world")
+        wt.commit(message="change hello", rev_id=b"bloe")
         wt.set_last_revision(b"bla")
         b.generate_revision_history(b"bla")
-        with open('hello', 'w') as f:
-            f.write('world')
-        wt.commit(message='change hello', rev_id=b"bla2")
+        with open("hello", "w") as f:
+            f.write("world")
+        wt.commit(message="change hello", rev_id=b"bla2")
 
         wt.branch.repository.lock_write()
         newrev = CommitBuilderRevisionRewriter(wt.branch.repository)(
-            b"bla2", b"bla4", (b"bloe",))
+            b"bla2", b"bla4", (b"bloe",)
+        )
         self.assertEqual(b"bla4", newrev)
         self.assertTrue(wt.branch.repository.has_revision(newrev))
         self.assertEqual(
-            (b"bloe",), wt.branch.repository.get_parent_map([newrev])[newrev])
+            (b"bloe",), wt.branch.repository.get_parent_map([newrev])[newrev]
+        )
         self.assertEqual(
-            "bla2", wt.branch.repository.get_revision(newrev).properties["rebase-of"])
+            "bla2", wt.branch.repository.get_revision(newrev).properties["rebase-of"]
+        )
         wt.branch.repository.unlock()
 
 
 class PlanCreatorTests(TestCaseWithTransport):
-
     def test_simple_plan_creator(self):
-        wt = self.make_branch_and_tree('.')
+        wt = self.make_branch_and_tree(".")
         b = wt.branch
-        with open('hello', 'w') as f:
-            f.write('hello world')
-        wt.add('hello')
-        wt.commit(message='add hello', rev_id=b"bla")
-        with open('hello', 'w') as f:
-            f.write('world')
-        wt.commit(message='change hello', rev_id=b"bloe")
+        with open("hello", "w") as f:
+            f.write("hello world")
+        wt.add("hello")
+        wt.commit(message="add hello", rev_id=b"bla")
+        with open("hello", "w") as f:
+            f.write("world")
+        wt.commit(message="change hello", rev_id=b"bloe")
         wt.set_last_revision(b"bla")
         b.generate_revision_history(b"bla")
-        with open('hello', 'w') as f:
-            f.write('world')
-        wt.commit(message='change hello', rev_id=b"bla2")
+        with open("hello", "w") as f:
+            f.write("world")
+        wt.commit(message="change hello", rev_id=b"bla2")
 
         b.repository.lock_read()
         graph = b.repository.get_graph()
         self.assertEqual(
-            {b'bla2': (b'newbla2', (b"bloe",))},
+            {b"bla2": (b"newbla2", (b"bloe",))},
             generate_simple_plan(
                 graph.find_difference(b.last_revision(), b"bla")[0],
-                b"bla2", None, b"bloe", graph, lambda y, _: b"new" + y))
+                b"bla2",
+                None,
+                b"bloe",
+                graph,
+                lambda y, _: b"new" + y,
+            ),
+        )
         b.repository.unlock()
 
     def test_simple_plan_creator_extra_history(self):
-        wt = self.make_branch_and_tree('.')
+        wt = self.make_branch_and_tree(".")
         b = wt.branch
-        with open('hello', 'w') as f:
-            f.write('hello world')
-        wt.add('hello')
-        wt.commit(message='add hello', rev_id=b"bla")
-        with open('hello', 'w') as f:
-            f.write('world')
-        wt.commit(message='change hello', rev_id=b"bloe")
+        with open("hello", "w") as f:
+            f.write("hello world")
+        wt.add("hello")
+        wt.commit(message="add hello", rev_id=b"bla")
+        with open("hello", "w") as f:
+            f.write("world")
+        wt.commit(message="change hello", rev_id=b"bloe")
         wt.set_last_revision(b"bla")
         b.generate_revision_history(b"bla")
-        with open('hello', 'w') as f:
-            f.write('world')
-        wt.commit(message='change hello', rev_id=b"bla2")
-        with open('hello', 'w') as f:
-            f.write('universe')
-        wt.commit(message='change hello again', rev_id=b"bla3")
+        with open("hello", "w") as f:
+            f.write("world")
+        wt.commit(message="change hello", rev_id=b"bla2")
+        with open("hello", "w") as f:
+            f.write("universe")
+        wt.commit(message="change hello again", rev_id=b"bla3")
 
         with b.repository.lock_read():
             graph = b.repository.get_graph()
             self.assertEqual(
-                {b'bla2': (b'newbla2', (b"bloe",)), b'bla3': (b'newbla3', (b'newbla2',))},
+                {
+                    b"bla2": (b"newbla2", (b"bloe",)),
+                    b"bla3": (b"newbla3", (b"newbla2",)),
+                },
                 generate_simple_plan(
                     graph.find_difference(b.last_revision(), b"bloe")[0],
-                    b"bla2", None, b"bloe",
-                    graph, lambda y, _: b"new" + y))
+                    b"bla2",
+                    None,
+                    b"bloe",
+                    graph,
+                    lambda y, _: b"new" + y,
+                ),
+            )
 
     def test_generate_transpose_plan(self):
-        wt = self.make_branch_and_tree('.')
+        wt = self.make_branch_and_tree(".")
         b = wt.branch
-        with open('hello', 'w') as f:
-            f.write('hello world')
-        wt.add('hello')
-        wt.commit(message='add hello', rev_id=b"bla")
-        with open('hello', 'w') as f:
-            f.write('world')
-        wt.commit(message='change hello', rev_id=b"bloe")
+        with open("hello", "w") as f:
+            f.write("hello world")
+        wt.add("hello")
+        wt.commit(message="add hello", rev_id=b"bla")
+        with open("hello", "w") as f:
+            f.write("world")
+        wt.commit(message="change hello", rev_id=b"bloe")
         wt.set_last_revision(b"bla")
         b.generate_revision_history(b"bla")
-        with open('hello', 'w') as f:
-            f.write('world')
-        wt.commit(message='change hello', rev_id=b"bla2")
-        with open('hello', 'w') as f:
-            f.write('universe')
-        wt.commit(message='change hello again', rev_id=b"bla3")
+        with open("hello", "w") as f:
+            f.write("world")
+        wt.commit(message="change hello", rev_id=b"bla2")
+        with open("hello", "w") as f:
+            f.write("universe")
+        wt.commit(message="change hello again", rev_id=b"bla3")
         wt.set_last_revision(b"bla")
         b.generate_revision_history(b"bla")
-        with open('hello', 'w') as f:
-            f.write('somebar')
-        wt.commit(message='change hello yet again', rev_id=b"blie")
+        with open("hello", "w") as f:
+            f.write("somebar")
+        wt.commit(message="change hello yet again", rev_id=b"blie")
         wt.set_last_revision(NULL_REVISION)
         b.generate_revision_history(NULL_REVISION)
-        wt.add('hello')
-        wt.commit(message='add hello', rev_id=b"lala")
+        wt.add("hello")
+        wt.commit(message="add hello", rev_id=b"lala")
 
         b.repository.lock_read()
         graph = b.repository.get_graph()
-        self.assertEqual({
-            b'blie': (b'newblie', (b'lala',))},
-            generate_transpose_plan(graph.iter_ancestry(
-                [b"blie"]),
-                {b"bla": b"lala"}, graph, lambda y, _: b"new" + y))
-        self.assertEqual({
-            b'bla2': (b'newbla2', (b'lala',)),
-            b'bla3': (b'newbla3', (b'newbla2',)),
-            b'blie': (b'newblie', (b'lala',)),
-            b'bloe': (b'newbloe', (b'lala',))},
-            generate_transpose_plan(graph.iter_ancestry(
-                b.repository._all_revision_ids()),
-                {b"bla": b"lala"}, graph, lambda y, _: b"new" + y))
+        self.assertEqual(
+            {b"blie": (b"newblie", (b"lala",))},
+            generate_transpose_plan(
+                graph.iter_ancestry([b"blie"]),
+                {b"bla": b"lala"},
+                graph,
+                lambda y, _: b"new" + y,
+            ),
+        )
+        self.assertEqual(
+            {
+                b"bla2": (b"newbla2", (b"lala",)),
+                b"bla3": (b"newbla3", (b"newbla2",)),
+                b"blie": (b"newblie", (b"lala",)),
+                b"bloe": (b"newbloe", (b"lala",)),
+            },
+            generate_transpose_plan(
+                graph.iter_ancestry(b.repository._all_revision_ids()),
+                {b"bla": b"lala"},
+                graph,
+                lambda y, _: b"new" + y,
+            ),
+        )
         b.repository.unlock()
 
     def test_generate_transpose_plan_one(self):
         graph = Graph(DictParentsProvider({"bla": ("bloe",), "bloe": (), "lala": ()}))
         self.assertEqual(
             {"bla": ("newbla", ("lala",))},
-            generate_transpose_plan(graph.iter_ancestry(
-                ["bla", "bloe"]), {"bloe": "lala"}, graph, lambda y, _: "new" + y))
+            generate_transpose_plan(
+                graph.iter_ancestry(["bla", "bloe"]),
+                {"bloe": "lala"},
+                graph,
+                lambda y, _: "new" + y,
+            ),
+        )
 
     def test_plan_with_already_merged(self):
         r"""We need to use a merge base that makes sense.
@@ -212,18 +256,14 @@ class PlanCreatorTests(TestCaseWithTransport):
         D -> (D', [C])
         E -> (E', [D', C])
         """
-        parents_map = {
-            "A": (),
-            "B": ("A",),
-            "C": ("B",),
-            "D": ("A",),
-            "E": ("D", "B")
-        }
+        parents_map = {"A": (), "B": ("A",), "C": ("B",), "D": ("A",), "E": ("D", "B")}
         graph = Graph(DictParentsProvider(parents_map))
         self.assertEqual(
             {"D": ("D'", ("C",)), "E": ("E'", ("D'",))},
             generate_simple_plan(
-                ["D", "E"], "D", None, "C", graph, lambda y, _: y + "'"))
+                ["D", "E"], "D", None, "C", graph, lambda y, _: y + "'"
+            ),
+        )
 
     def test_plan_with_already_merged_skip_merges(self):
         r"""We need to use a merge base that makes sense.
@@ -242,25 +282,20 @@ class PlanCreatorTests(TestCaseWithTransport):
 
         D -> (D', [C])
         """
-        parents_map = {
-            "A": (),
-            "B": ("A",),
-            "C": ("B",),
-            "D": ("A",),
-            "E": ("D", "B")
-        }
+        parents_map = {"A": (), "B": ("A",), "C": ("B",), "D": ("A",), "E": ("D", "B")}
         graph = Graph(DictParentsProvider(parents_map))
         self.assertEqual(
             {"D": ("D'", ("C",))},
             generate_simple_plan(
-                ["D", "E"], "D", None, "C", graph, lambda y, _: y + "'", True))
+                ["D", "E"], "D", None, "C", graph, lambda y, _: y + "'", True
+            ),
+        )
 
 
 class RebaseStateTests(TestCaseWithTransport):
-
     def setUp(self):
         super().setUp()
-        self.wt = self.make_branch_and_tree('.')
+        self.wt = self.make_branch_and_tree(".")
         self.state = RebaseState1(self.wt)
 
     def test_rebase_plan_exists_false(self):
@@ -284,16 +319,18 @@ class RebaseStateTests(TestCaseWithTransport):
         self.assertFalse(self.state.has_plan())
 
     def test_write_rebase_plan(self):
-        with open('hello', 'w') as f:
-            f.write('hello world')
-        self.wt.add('hello')
-        self.wt.commit(message='add hello', rev_id=b"bla")
-        self.state.write_plan(
-            {b"oldrev": (b"newrev", [b"newparent1", b"newparent2"])})
-        self.assertEqualDiff(b"""# Bazaar rebase plan 1
+        with open("hello", "w") as f:
+            f.write("hello world")
+        self.wt.add("hello")
+        self.wt.commit(message="add hello", rev_id=b"bla")
+        self.state.write_plan({b"oldrev": (b"newrev", [b"newparent1", b"newparent2"])})
+        self.assertEqualDiff(
+            b"""# Bazaar rebase plan 1
 1 bla
 oldrev newrev newparent1 newparent2
-""", self.wt._transport.get_bytes(REBASE_PLAN_FILENAME))
+""",
+            self.wt._transport.get_bytes(REBASE_PLAN_FILENAME),
+        )
 
     def test_read_rebase_plan_nonexistant(self):
         self.assertRaises(NoSuchFile, self.state.read_plan)
@@ -308,10 +345,12 @@ oldrev newrev newparent1 newparent2
             b"""# Bazaar rebase plan 1
 1 bla
 oldrev newrev newparent1 newparent2
-""")
+""",
+        )
         self.assertEqual(
             ((1, b"bla"), {b"oldrev": (b"newrev", (b"newparent1", b"newparent2"))}),
-            self.state.read_plan())
+            self.state.read_plan(),
+        )
 
     def test_read_nonexistant(self):
         self.assertIs(None, self.state.read_active_revid())
@@ -334,38 +373,43 @@ oldrev newrev newparent1 newparent2
 
 
 class RebaseTodoTests(TestCase):
-
     def test_done(self):
         class Repository:
             def has_revision(self, revid):
                 return revid == "bloe"
-        self.assertEqual(
-            [], list(rebase_todo(Repository(), {"bla": ("bloe", [])})))
+
+        self.assertEqual([], list(rebase_todo(Repository(), {"bla": ("bloe", [])})))
 
     def test_notstarted(self):
         class Repository:
             def has_revision(self, revid):
                 return False
-        self.assertEqual(["bla"], list(rebase_todo(Repository(), {"bla": ("bloe", [])})))
+
+        self.assertEqual(
+            ["bla"], list(rebase_todo(Repository(), {"bla": ("bloe", [])}))
+        )
 
     def test_halfway(self):
         class Repository:
             def has_revision(self, revid):
                 return revid == "bloe"
+
         self.assertEqual(
             ["ha"],
-            list(rebase_todo(Repository(), {"bla": ("bloe", []), "ha": ("hee", [])})))
+            list(rebase_todo(Repository(), {"bla": ("bloe", []), "ha": ("hee", [])})),
+        )
 
 
 class ReplaySnapshotTests(TestCaseWithTransport):
-
     def test_single_revision(self):
         wt = self.make_branch_and_tree(".")
-        self.build_tree(['afile'])
+        self.build_tree(["afile"])
         wt.add(["afile"])
         wt.commit("bla", rev_id=b"oldcommit")
         wt.branch.repository.lock_write()
-        CommitBuilderRevisionRewriter(wt.branch.repository)(b"oldcommit", b"newcommit", ())
+        CommitBuilderRevisionRewriter(wt.branch.repository)(
+            b"oldcommit", b"newcommit", ()
+        )
         wt.branch.repository.unlock()
         oldrev = wt.branch.repository.get_revision(b"oldcommit")
         newrev = wt.branch.repository.get_revision(b"newcommit")
@@ -379,20 +423,25 @@ class ReplaySnapshotTests(TestCaseWithTransport):
 
     def test_two_revisions(self):
         wt = self.make_branch_and_tree("old")
-        self.build_tree_contents([('old/afile', 'afilecontents'), ('old/notherfile', 'notherfilecontents')])
+        self.build_tree_contents(
+            [("old/afile", "afilecontents"), ("old/notherfile", "notherfilecontents")]
+        )
         wt.add(["afile"], ids=[b"somefileid"])
         wt.commit("bla", rev_id=b"oldparent")
         wt.add(["notherfile"])
         wt.commit("bla", rev_id=b"oldcommit")
         oldrepos = wt.branch.repository
         wt = self.make_branch_and_tree("new")
-        self.build_tree_contents([('new/afile', 'afilecontents'), ('new/notherfile', 'notherfilecontents')])
+        self.build_tree_contents(
+            [("new/afile", "afilecontents"), ("new/notherfile", "notherfilecontents")]
+        )
         wt.add(["afile"], ids=[b"afileid"])
         wt.commit("bla", rev_id=b"newparent")
         wt.branch.repository.fetch(oldrepos)
         wt.branch.repository.lock_write()
         CommitBuilderRevisionRewriter(wt.branch.repository)(
-            b"oldcommit", b"newcommit", (b"newparent",))
+            b"oldcommit", b"newcommit", (b"newparent",)
+        )
         wt.branch.repository.unlock()
         oldrev = wt.branch.repository.get_revision(b"oldcommit")
         newrev = wt.branch.repository.get_revision(b"newcommit")
@@ -407,27 +456,33 @@ class ReplaySnapshotTests(TestCaseWithTransport):
 
     def test_two_revisions_no_renames(self):
         wt = self.make_branch_and_tree("old")
-        self.build_tree(['old/afile', 'old/notherfile'])
+        self.build_tree(["old/afile", "old/notherfile"])
         wt.add(["afile"], ids=[b"somefileid"])
         wt.commit("bla", rev_id=b"oldparent")
         wt.add(["notherfile"])
         wt.commit("bla", rev_id=b"oldcommit")
         oldrepos = wt.branch.repository
         wt = self.make_branch_and_tree("new")
-        self.build_tree(['new/afile', 'new/notherfile'])
+        self.build_tree(["new/afile", "new/notherfile"])
         wt.add(["afile"], ids=[b"afileid"])
         wt.commit("bla", rev_id=b"newparent")
         wt.branch.repository.fetch(oldrepos)
         wt.branch.repository.lock_write()
         CommitBuilderRevisionRewriter(wt.branch.repository)(
-            b"oldcommit", b"newcommit", (b"newparent",))
+            b"oldcommit", b"newcommit", (b"newparent",)
+        )
         wt.branch.repository.unlock()
 
     def test_multi_revisions(self):
         wt = self.make_branch_and_tree("old")
         self.build_tree_contents(
-            [('old/afile', 'afilecontent'), ('old/sfile', 'sfilecontent'), ('old/notherfile', 'notherfilecontent')])
-        wt.add(['sfile'])
+            [
+                ("old/afile", "afilecontent"),
+                ("old/sfile", "sfilecontent"),
+                ("old/notherfile", "notherfilecontent"),
+            ]
+        )
+        wt.add(["sfile"])
         wt.add(["afile"], ids=[b"somefileid"])
         wt.commit("bla", rev_id=b"oldgrandparent")
         with open("old/afile", "w") as f:
@@ -438,8 +493,13 @@ class ReplaySnapshotTests(TestCaseWithTransport):
         oldrepos = wt.branch.repository
         wt = self.make_branch_and_tree("new")
         self.build_tree_contents(
-            [('new/afile', 'afilecontent'), ('new/sfile', 'sfilecontent'), ('new/notherfile', 'notherfilecontent')])
-        wt.add(['sfile'])
+            [
+                ("new/afile", "afilecontent"),
+                ("new/sfile", "sfilecontent"),
+                ("new/notherfile", "notherfilecontent"),
+            ]
+        )
+        wt.add(["sfile"])
         wt.add(["afile"], ids=[b"afileid"])
         wt.commit("bla", rev_id=b"newgrandparent")
         with open("new/afile", "w") as f:
@@ -448,7 +508,8 @@ class ReplaySnapshotTests(TestCaseWithTransport):
         wt.branch.repository.fetch(oldrepos)
         wt.branch.repository.lock_write()
         CommitBuilderRevisionRewriter(wt.branch.repository)(
-            b"oldcommit", b"newcommit", (b"newparent",))
+            b"oldcommit", b"newcommit", (b"newparent",)
+        )
         wt.branch.repository.unlock()
         oldrev = wt.branch.repository.get_revision(b"oldcommit")
         newrev = wt.branch.repository.get_revision(b"newcommit")
@@ -465,7 +526,7 @@ class ReplaySnapshotTests(TestCaseWithTransport):
     def test_maps_ids(self):
         wt = self.make_branch_and_tree("old")
         wt.commit("base", rev_id=b"base")
-        self.build_tree(['old/afile'])
+        self.build_tree(["old/afile"])
         wt.add(["afile"], ids=[b"originalid"])
         wt.commit("bla", rev_id=b"oldparent")
         with open("old/afile", "w") as f:
@@ -473,13 +534,14 @@ class ReplaySnapshotTests(TestCaseWithTransport):
         wt.commit("bla", rev_id=b"oldcommit")
         oldrepos = wt.branch.repository
         wt = self.make_branch_and_tree("new")
-        self.build_tree(['new/afile'])
+        self.build_tree(["new/afile"])
         wt.add(["afile"], ids=[b"newid"])
         wt.commit("bla", rev_id=b"newparent")
         wt.branch.repository.fetch(oldrepos)
         wt.branch.repository.lock_write()
         CommitBuilderRevisionRewriter(wt.branch.repository)(
-            b"oldcommit", b"newcommit", (b"newparent",))
+            b"oldcommit", b"newcommit", (b"newparent",)
+        )
         wt.branch.repository.unlock()
         oldrev = wt.branch.repository.get_revision(b"oldcommit")
         newrev = wt.branch.repository.get_revision(b"newcommit")
@@ -497,7 +559,7 @@ class TestReplayWorkingtree(TestCaseWithTransport):
     def test_conflicts(self):
         wt = self.make_branch_and_tree("old")
         wt.commit("base", rev_id=b"base")
-        self.build_tree(['old/afile'])
+        self.build_tree(["old/afile"])
         wt.add(["afile"], ids=[b"originalid"])
         wt.commit("bla", rev_id=b"oldparent")
         with open("old/afile", "w") as f:
@@ -505,7 +567,7 @@ class TestReplayWorkingtree(TestCaseWithTransport):
         wt.commit("bla", rev_id=b"oldcommit")
         oldrepos = wt.branch.repository
         wt = self.make_branch_and_tree("new")
-        self.build_tree(['new/afile'])
+        self.build_tree(["new/afile"])
         wt.add(["afile"], ids=[b"newid"])
         wt.commit("bla", rev_id=b"newparent")
         wt.branch.repository.fetch(oldrepos)
@@ -513,20 +575,23 @@ class TestReplayWorkingtree(TestCaseWithTransport):
             replayer = WorkingTreeRevisionRewriter(wt, RebaseState1(wt))
             self.assertRaises(
                 ConflictsInTree,
-                replayer, b"oldcommit", b"newcommit",
-                [b"newparent"], )
+                replayer,
+                b"oldcommit",
+                b"newcommit",
+                [b"newparent"],
+            )
 
     def test_simple(self):
         wt = self.make_branch_and_tree("old")
         wt.commit("base", rev_id=b"base")
-        self.build_tree(['old/afile'])
+        self.build_tree(["old/afile"])
         wt.add(["afile"], ids=[b"originalid"])
         wt.commit("bla", rev_id=b"oldparent")
         with open("old/afile", "w") as f:
             f.write("bloe")
         wt.commit("bla", rev_id=b"oldcommit")
         wt = wt.controldir.sprout("new").open_workingtree()
-        self.build_tree(['new/bfile'])
+        self.build_tree(["new/bfile"])
         wt.add(["bfile"], ids=[b"newid"])
         wt.commit("bla", rev_id=b"newparent")
         replayer = WorkingTreeRevisionRewriter(wt, RebaseState1(wt))
@@ -550,7 +615,7 @@ class TestReplayWorkingtree(TestCaseWithTransport):
         wt = self.make_branch_and_tree("old")
         wt.commit("base", rev_id=b"base")
         # oldparent:
-        self.build_tree_contents([('old/afile', 'base content')])
+        self.build_tree_contents([("old/afile", "base content")])
         wt.add(["afile"], ids=[b"originalid"])
         wt.commit("bla", rev_id=b"oldparent")
         # oldcommit (the delta getting rebased)
@@ -560,11 +625,10 @@ class TestReplayWorkingtree(TestCaseWithTransport):
         wt.add_pending_merge(b"ghost")
         wt.commit("bla", rev_id=b"oldcommit")
         # newparent (the new base for the rebased commit)
-        new_tree = wt.controldir.sprout(
-            "new", revision_id=b'base').open_workingtree()
+        new_tree = wt.controldir.sprout("new", revision_id=b"base").open_workingtree()
         new_tree.branch.repository.fetch(wt.branch.repository)
         wt = new_tree
-        self.build_tree_contents([('new/afile', 'base content')])
+        self.build_tree_contents([("new/afile", "base content")])
         wt.add(["afile"], ids=[b"originalid"])
         wt.commit("bla", rev_id=b"newparent")
         # And do it!
@@ -604,7 +668,7 @@ class TestReplayWorkingtree(TestCaseWithTransport):
 
         """
         oldwt = self.make_branch_and_tree("old")
-        self.build_tree(['old/afile'])
+        self.build_tree(["old/afile"])
         with open("old/afile", "w") as f:
             f.write("A\n" * 10)
         oldwt.add(["afile"])
@@ -616,7 +680,7 @@ class TestReplayWorkingtree(TestCaseWithTransport):
         with open("old/afile", "w") as f:
             f.write("A\n" * 10 + "C\n")
         oldwt.commit("bla", rev_id=b"C")
-        self.build_tree(['new/bfile'])
+        self.build_tree(["new/bfile"])
         newwt.add(["bfile"])
         with open("new/bfile", "w") as f:
             f.write("D\n")
@@ -647,11 +711,10 @@ class TestReplayWorkingtree(TestCaseWithTransport):
         newrev = newwt.branch.repository.get_revision(b"E'")
         self.assertEqual([b"D'"], newrev.parent_ids)
         self.assertThat(
-            newwt.branch,
-            RevisionHistoryMatches([b"A", b"B", b"C", b"D'", b"E'"]))
+            newwt.branch, RevisionHistoryMatches([b"A", b"B", b"C", b"D'", b"E'"])
+        )
 
 
 class TestReplaySnapshotError(TestCase):
-
     def test_create(self):
         ReplaySnapshotError("message")
