@@ -33,13 +33,13 @@ from ...bzr import BzrProber, register_metadir, serializer
 # constraints (simple string, unique, immutable).
 _mod_repository.network_format_registry.register_lazy(
     b"Bazaar-NG branch, format 5\n",
-    'breezy.plugins.weave_fmt.repository',
-    'RepositoryFormat5',
+    "breezy.plugins.weave_fmt.repository",
+    "RepositoryFormat5",
 )
 _mod_repository.network_format_registry.register_lazy(
     b"Bazaar-NG branch, format 6\n",
-    'breezy.plugins.weave_fmt.repository',
-    'RepositoryFormat6',
+    "breezy.plugins.weave_fmt.repository",
+    "RepositoryFormat6",
 )
 
 # weave formats which has no format string and are not discoverable or independently
@@ -49,73 +49,88 @@ _mod_repository.network_format_registry.register_lazy(
 # the repository is not separately opened are similar.
 
 _mod_repository.format_registry.register_lazy(
-    b'Bazaar-NG Repository format 7',
-    'breezy.plugins.weave_fmt.repository',
-    'RepositoryFormat7'
-    )
+    b"Bazaar-NG Repository format 7",
+    "breezy.plugins.weave_fmt.repository",
+    "RepositoryFormat7",
+)
 
 _mod_repository.format_registry.register_extra_lazy(
-    'breezy.plugins.weave_fmt.repository',
-    'RepositoryFormat4')
+    "breezy.plugins.weave_fmt.repository", "RepositoryFormat4"
+)
 _mod_repository.format_registry.register_extra_lazy(
-    'breezy.plugins.weave_fmt.repository',
-    'RepositoryFormat5')
+    "breezy.plugins.weave_fmt.repository", "RepositoryFormat5"
+)
 _mod_repository.format_registry.register_extra_lazy(
-    'breezy.plugins.weave_fmt.repository',
-    'RepositoryFormat6')
+    "breezy.plugins.weave_fmt.repository", "RepositoryFormat6"
+)
 
 
 # The pre-0.8 formats have their repository format network name registered in
 # repository.py. MetaDir formats have their repository format network name
 # inferred from their disk format string.
-controldir.format_registry.register_lazy('weave',
-                                         "breezy.plugins.weave_fmt.bzrdir", "BzrDirFormat6",
-                                         'Pre-0.8 format.  Slower than knit and does not'
-                                         ' support checkouts or shared repositories.',
-                                         hidden=True,
-                                         deprecated=True)
-register_metadir(controldir.format_registry, 'metaweave',
-                 'breezy.plugins.weave_fmt.repository.RepositoryFormat7',
-                 'Transitional format in 0.8.  Slower than knit.',
-                 branch_format='breezy.bzr.fullhistory.BzrBranchFormat5',
-                 tree_format='breezy.bzr.workingtree_3.WorkingTreeFormat3',
-                 hidden=True,
-                 deprecated=True)
+controldir.format_registry.register_lazy(
+    "weave",
+    "breezy.plugins.weave_fmt.bzrdir",
+    "BzrDirFormat6",
+    "Pre-0.8 format.  Slower than knit and does not"
+    " support checkouts or shared repositories.",
+    hidden=True,
+    deprecated=True,
+)
+register_metadir(
+    controldir.format_registry,
+    "metaweave",
+    "breezy.plugins.weave_fmt.repository.RepositoryFormat7",
+    "Transitional format in 0.8.  Slower than knit.",
+    branch_format="breezy.bzr.fullhistory.BzrBranchFormat5",
+    tree_format="breezy.bzr.workingtree_3.WorkingTreeFormat3",
+    hidden=True,
+    deprecated=True,
+)
 
 
 BzrProber.formats.register_lazy(
-    b"Bazaar-NG branch, format 0.0.4\n", "breezy.plugins.weave_fmt.bzrdir",
-    "BzrDirFormat4")
+    b"Bazaar-NG branch, format 0.0.4\n",
+    "breezy.plugins.weave_fmt.bzrdir",
+    "BzrDirFormat4",
+)
 BzrProber.formats.register_lazy(
-    b"Bazaar-NG branch, format 5\n", "breezy.plugins.weave_fmt.bzrdir",
-    "BzrDirFormat5")
+    b"Bazaar-NG branch, format 5\n", "breezy.plugins.weave_fmt.bzrdir", "BzrDirFormat5"
+)
 BzrProber.formats.register_lazy(
-    b"Bazaar-NG branch, format 6\n", "breezy.plugins.weave_fmt.bzrdir",
-    "BzrDirFormat6")
+    b"Bazaar-NG branch, format 6\n", "breezy.plugins.weave_fmt.bzrdir", "BzrDirFormat6"
+)
 
 
 _mod_branch.format_registry.register_extra_lazy(
-    'breezy.plugins.weave_fmt.branch', 'BzrBranchFormat4')
+    "breezy.plugins.weave_fmt.branch", "BzrBranchFormat4"
+)
 _mod_branch.network_format_registry.register_lazy(
     b"Bazaar-NG branch, format 6\n",
-    'breezy.plugins.weave_fmt.branch', "BzrBranchFormat4")
+    "breezy.plugins.weave_fmt.branch",
+    "BzrBranchFormat4",
+)
 
 
 _mod_workingtree.format_registry.register_extra_lazy(
-    'breezy.plugins.weave_fmt.workingtree',
-    'WorkingTreeFormat2')
+    "breezy.plugins.weave_fmt.workingtree", "WorkingTreeFormat2"
+)
 
-serializer.format_registry.register_lazy('4', 'breezy.plugins.weave_fmt.xml4',
-                                         'serializer_v4')
+serializer.format_registry.register_lazy(
+    "4", "breezy.plugins.weave_fmt.xml4", "serializer_v4"
+)
 
 
 def load_tests(loader, basic_tests, pattern):
     testmod_names = [
-        'test_bzrdir',
-        'test_repository',
-        'test_store',
-        'test_workingtree',
-        ]
-    basic_tests.addTest(loader.loadTestsFromModuleNames(
-        ["{}.{}".format(__name__, tmn) for tmn in testmod_names]))
+        "test_bzrdir",
+        "test_repository",
+        "test_store",
+        "test_workingtree",
+    ]
+    basic_tests.addTest(
+        loader.loadTestsFromModuleNames(
+            ["{}.{}".format(__name__, tmn) for tmn in testmod_names]
+        )
+    )
     return basic_tests
