@@ -3,15 +3,15 @@
 import os
 import sys
 
-sys.path.append(os.path.join(os.path.dirname(__file__), '..'))
+sys.path.append(os.path.join(os.path.dirname(__file__), ".."))
 import brzflakes
 
 
 class LazyImport:
     """A dummy plugin that is present mainly to monkey patch pyflakes."""
 
-    name = 'lazy-import'
-    version = '0.1'
+    name = "lazy-import"
+    version = "0.1"
 
     def __init__(self, tree):
         self.tree = tree
